@@ -153,7 +153,7 @@ void init_object(py::module_& m);
 
 // From object_repr.cpp
 std::string objecthandle_scalar_value(QPDFObjectHandle h, bool escaped=true);
-std::string objecthandle_pythonic_typename(QPDFObjectHandle h, std::string prefix = "pikepdf.");
+std::string objecthandle_pythonic_typename(QPDFObjectHandle h);
 std::string objecthandle_repr_typename_and_value(QPDFObjectHandle h);
 std::string objecthandle_repr(QPDFObjectHandle h);
 
